#
# spec file for package jackson-dataformats-binary
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with extra_dataformats
# Extra formats are disabled because of circular dependencies
Name:           jackson-dataformats-binary
Version:        2.13.0
Release:        150200.3.3.3
Summary:        Jackson standard binary data format backends
License:        Apache-2.0 AND BSD-3-Clause
Group:          Development/Libraries/Java
URL:            https://github.com/FasterXML/jackson-dataformats-binary
Source0:        https://github.com/FasterXML/jackson-dataformats-binary/archive/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-annotations) >= %{version}
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-core) >= %{version}
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-databind) >= %{version}
BuildRequires:  mvn(com.fasterxml.jackson:jackson-base:pom:) >= %{version}
BuildRequires:  mvn(com.google.code.maven-replacer-plugin:replacer)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildArch:      noarch
%if %{with extra_dataformats}
BuildRequires:  mvn(ch.qos.logback:logback-classic)
BuildRequires:  mvn(com.squareup:protoparser)
BuildRequires:  mvn(org.apache.avro:avro)
BuildRequires:  mvn(org.assertj:assertj-core)
%endif

%description
Parent pom for Jackson binary dataformats.

%if %{with extra_dataformats}
%package -n jackson-dataformat-avro
Summary:        Support for reading and writing AVRO-encoded data via Jackson abstractions
Group:          Development/Libraries/Java

%description -n jackson-dataformat-avro
Jackson extension component for reading and writing data encoded using Apache
Avro data format. Project adds necessary abstractions on top to make things
work with other Jackson functionality. It relies on standard Avro library for
Avro Schema handling, and some parts of deserialization/serialization.

%package -n jackson-dataformat-protobuf
Summary:        Support for reading and writing protobuf-encoded data via Jackson abstractions
Group:          Development/Libraries/Java

%description -n jackson-dataformat-protobuf
Jackson extension component for reading and writing Protobuf encoded data
(see protobuf encoding spec). This project adds necessary abstractions on top
to make things work with other Jackson functionality; mostly just low-level
Streaming components (JsonFactory, JsonParser, JsonGenerator).
%endif

%package -n jackson-dataformat-cbor
Summary:        Support for reading and writing Concise Binary Object Representation
Group:          Development/Libraries/Java

%description -n jackson-dataformat-cbor
Jackson data format module that supports reading and writing CBOR ("Concise
Binary Object Representation") encoded data. Module extends standard Jackson
streaming API (JsonFactory, JsonParser, JsonGenerator), and as such works
seamlessly with all the higher level data abstractions (data binding, tree
model, and pluggable extensions).

%package -n jackson-dataformat-smile
Summary:        Support for reading and writing Smile encoded data using Jackson abstractions
Group:          Development/Libraries/Java

%description -n jackson-dataformat-smile
This Jackson extension handles reading and writing of data encoded in Smile
data format ("binary JSON"). It extends standard Jackson streaming API
(JsonFactory, JsonParser, JsonGenerator), and as such works seamlessly with
all the higher level data abstractions (data binding, tree model, and
pluggable extensions).

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}

cp -p ion/LICENSE .
cp -p ion/NOTICE .
sed -i 's/\r//' LICENSE NOTICE

%if %{without extra_dataformats}
%pom_disable_module avro
%pom_disable_module protobuf
%endif

# Remove plugins unnecessary for RPM builds
%pom_remove_plugin -r org.moditect:moditect-maven-plugin
%pom_remove_plugin -r :gradle-module-metadata-maven-plugin
%pom_remove_plugin -r :jacoco-maven-plugin

# Deps are not available in packages for this module
%pom_disable_module ion

%{mvn_file} ":{*}" jackson-dataformats/@1

%build
%{mvn_build} -s -f

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles-jackson-dataformats-binary
%doc README.md release-notes/*
%license LICENSE NOTICE

%if %{with extra_dataformats}
%files -n jackson-dataformat-avro -f .mfiles-jackson-dataformat-avro
%doc avro/README.md avro/release-notes/*
%license LICENSE NOTICE

%files -n jackson-dataformat-protobuf -f .mfiles-jackson-dataformat-protobuf
%doc protobuf/README.md protobuf/release-notes/*
%license LICENSE NOTICE
%endif

%files -n jackson-dataformat-cbor -f .mfiles-jackson-dataformat-cbor
%doc cbor/README.md cbor/release-notes/*
%license LICENSE NOTICE

%files -n jackson-dataformat-smile -f .mfiles-jackson-dataformat-smile
%doc smile/README.md smile/release-notes/*
%license LICENSE NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE

%changelog
* Wed Oct 20 2021 fstrba@suse.com
- Version update to 2.13.0
  * 2.13.0 (30-Sep-2021)
    + #239: (cbor) Should validate UTF-8 multi-byte validity for
    short decode path too
    + #248: (ion) Deprecate 'CloseSafeUTF8Writer', remove use
    + #252: (smile) Make 'SmileFactory' support
    'JsonFactory.Feature.CANONICALIZE_FIELD_NAMES'
    + #253: (cbor) Make 'CBORFactory' support
    'JsonFactory.Feature.CANONICALIZE_FIELD_NAMES'
    + #264: (cbor) Handle case of BigDecimal with Integer.MIN_VALUE
    for scale gracefully
    + #272: (cbor) Uncaught exception in
    CBORParser._nextChunkedByte2 (by ossfuzzer)
    + #273: (cbor) Another uncaught exception in
    CBORParser._nextChunkedByte2 (by ossfuzzer)
    + #276: (smile) Add
    'SmileGenerator.Feature.LENIENT_UTF_ENCODING' for lenient
    handling of broken Unicode surrogate pairs on writing
    + #283: (avro) Add 'logicalType' support for some 'java.time'
    types; add 'AvroJavaTimeModule' for native ser/deser
    + #284: Support base64 strings in 'getBinaryValue()' for CBOR
    and Smile
    + #289: (cbor) 'ArrayIndexOutOfBounds' for truncated UTF-8 name
    + #290: (avro) Generate logicalType switch
    + #291: (smile) 'ArrayIndexOutOfBounds' for truncated UTF-8 name
    + #295: (ion) 'jackson-dataformat-ion' does not handle
    null.struct deserialization correctly
    + 'Ion-java' dep 1.4.0 -> 1.8.0
    + Minor change to Ion module registration names
    (fully-qualified)
  * 2.12.4 (06-Jul-2021)
    + #287: (cbor) Uncaught exception in
    CBORParser._nextChunkedByte2 (by ossfuzzer)
    + #288: (cbor) Uncaught exception in
    CBORParser._findDecodedFromSymbols() (by ossfuzzer)
  * 2.12.3 (12-Apr-2021)
    + #257: (smile) Uncaught validation problem wrt Smile
    "BigDecimal" type
    + #258: (smile) ArrayIndexOutOfBoundsException for malformed
    Smile header
    + #259: (cbor) Failed to handle case of alleged String with
    length of Integer.MAX_VALUE
    + #260: (smile) Allocate byte[] lazily for longer Smile binary
    data payloads
    + #261 (cbor) CBORParser need to validate zero-length byte[] for
    BigInteger
    + #263: (smile) Handle invalid chunked-binary-format length
    gracefully
    + #265: (smile) Allocate byte[] lazily for longer Smile binary
    data payloads (7-bit encoded)
    + #266: (smile)  ArrayIndexOutOfBoundsException in
    SmileParser._decodeShortUnicodeValue()
    + #268: (smile) Handle sequence of Smile header markers without
    recursion
    + #269: (cbor) CBOR loses 'Map' entries with specific 'long' Map
    key values (32-bit boundary)
    + #270: (ion) Ion Polymorphic deserialization in 2.12 breaks wrt
    use of Native Type Ids when upgrading from 2.8
  * 2.12.2 (03-Mar-2021)
    + #236: (cbor) 'ArrayIndexOutOfBoundsException' in 'CBORParser'
    for invalid UTF-8 String
    + #240: (cbor) Handle invalid CBOR content like '[0x84]'
    (incomplete array)
    + #241: (ion) Respect 'WRITE_ENUMS_USING_TO_STRING' in
    'EnumAsIonSymbolSerializer'
    + #242: (ion) Add support for generating IonSexps
    + #244: (ion) Add support for deserializing IonTimestamps and
    IonBlobs
    + #246: (ion) Add 'IonObjectMapper.builderForBinaryWriters()' /
    '.builderforTextualWriters()' convenience methods
    + #247: (ion) Enabling pretty-printing fails Ion serialization
  * 2.12.1 (08-Jan-2021)
    + #232: (ion) Allow disabling native type ids in IonMapper
    + #235: (smile) Small bug in byte-alignment for long field names
    in Smile, symbol table reuse
  * 2.12.0 (29-Nov-2020)
    + #204: (ion) Add 'IonFactory.getIonSystem()' accessor
    + #212: (ion) Optimize 'IonParser.getNumberType()' using
    'IonReader.getIntegerSize()'
    + #222: (cbor) Add 'CBORGenerator.Feature.LENIENT_UTF_ENCODING'
    for lenient handling of Unicode surrogate pairs on writing
    + #228: (cbor) Add support for decoding unassigned "simple
    values" (type 7)
    + Add Gradle Module Metadata
    (https://blog.gradle.org/alignment-with-gradle-module-metadata)
  * 2.11.4 (12-Dec-2020)
    + #186: (cbor) Eager allocation of byte buffer can cause
    'java.lang.OutOfMemoryError' exception (CVE-2020-28491)
  * 2.11.3 (02-Oct-2020)
    + #219: (avro) Cache record names to avoid hitting class loader
  * 2.11.2 (02-Aug-2020)
    + #216: (avro) Avro null deserialization
  * 2.11.1 (25-Jun-2020)
    + #204: (ion) Add 'IonFactory.getIonSystem()' accessor
  * 2.11.0 (26-Apr-2020)
    + #179: (avro) Add 'AvroGenerator.canWriteBinaryNatively()' to
    support binary writes, fix 'java.util.UUID' representation
    + #192: (ion) Allow 'IonObjectMapper' with class name annotation
    introspector to deserialize generic subtypes
    + #195: Remove dependencies upon Jackson 1.X and Avro's
    JacksonUtils
    + #198: 'jackson-databind' should not be full dependency for
    (cbor, protobuf, smile) modules
    + #201: 'CBORGenerator.Feature.WRITE_MINIMAL_INTS' does not
    write most compact form for all integers
    + 'AvroGenerator' overrides 'getOutputContext()' properly
  * 2.10.5 (21-Jul-2020)
    + #204: (ion) Add 'IonFactory.getIonSystem()' accessor
    + #211: (avro) Fix schema evolution involving maps of non-scalar
  * 2.10.4 (03-May-2020)
    + #202: (protobuf) Parsing a protobuf message doesn't properly
    skip unknown fields
  * 2.10.2 (05-Jan-2020)
    + #189: (ion) IonObjectMapper close()s the provided IonWriter
    unnecessarily
    + ion-java dependency 1.4.0 -> 1.5.1
* Wed Nov 20 2019 pmonrealgonzalez@suse.com
- Remove plugins unnecessary for RPM builds
  org.moditect:moditect-maven-plugin
* Wed Nov 20 2019 pmonrealgonzalez@suse.com
- Version update to 2.10.1
  * 2.10.1 (09-Nov-2019)
    + #185: Internal parsing of tagged arrays can lead to stack
    overflow
    + #188: Unexpected 'MismatchedInputException' for 'byte[]' value
    bound to 'String' in collection/array
  * 2.10.0 (26-Sep-2019)
    + #139: (cbor) Incorrect decimal fraction representation
    + #148: (protobuf) Add
    'ProtobufMapper.generateSchemaFor(TypeReference<?>)' overload
    + #155: (cbor, smile) Inconsistent support for
    FLUSH_PASSED_TO_STREAM
    + #157: (all) Add simple module-info for JDK9+, using Moditect
    + #163: (ion) Update 'ion-java' dependency
    + #168: (avro) 'JsonMappingException' for union types with
    multiple Record types
    + #173: (avro) Improve Union type serialization performance
    + #177: (avro) Deserialization of "empty" Records as root values
    fails
    + #178: (cbor) Fix issue wit input offsets when parsing CBOR
    from 'InputStream'
    + #180: (protobuf) Add
    'ProtobufGenerator.canWriteBinaryNatively()' to support binary
    writes
    + asm version upgrade to 6.2.1 (from 5.1)
    + (cbor, smile) Rewrote handling of "output context" for better
    field id write support
  * 2.9.9 (16-May-2019)
    + #159: (cbor) Some short UTF Strings encoded using
    non-canonical form
    + #161: (avro) Deserialize from newer version to older one
    throws NullPointerException
  * 2.9.8 (15-Dec-2018)
    + #140: (protobuf) Stack overflow when generating Protobuf
    schema on class with cyclic type definition
    + #153: (smile) Unable to set a compression input/output
    decorator to a 'SmileFactory'
  * 2.9.7 (19-Sep-2018)
    + #142: (ion) 'IonParser.getNumberType()' returns 'null' for
    'IonType.FLOAT'
    + #150: Add 'CBORMapper'
    + #151: Add 'SmileMapper'
  * 2.9.6 (12-Jun-2018)
    + #93: (cbor) 'CBORParser' does not accept "undefined value"
    + #135: (protobuf) Infinite sequence of 'END_OBJECT' tokens
    returned at end of streaming read
    + #136: (avro) Fix MapWriteContext not correctly resolving union
    values
  * 2.9.5 (26-Feb-2018)
    + #128 (protobuf) Fix skip unknown WireType.FIXED_64BIT value
    bug
    + #129 (cbor) Remove "final" modifier from 'CBORParser'
* Tue Nov 12 2019 fstrba@suse.com
- Initial packaging of jackson-dataformats-binary 2.9.4
